@@ -14,10 +14,11 @@ from time import mktime
 
 
 __copyright__ = 'Copyright 2012 by Heungsub Lee'
-__license__ = 'BSD License'
+__version__ = '0.1.2'
+__license__ = 'BSD'
 __author__ = 'Heungsub Lee'
-__email__ = 'h''@''subl.ee'
-__version__ = '0.1.1'
+__author_email__ = 'h''@''subl.ee'
+__url__ = 'http://packages.python.org/energy'
 __all__ = ['Energy']
 
 
@@ -67,8 +68,8 @@ class Energy(object):
     period of your players.
 
     :param max: maximum energy
-    :param recovery_interval: an interval in seconds to recover energy. It
-                              should be `int`, `float` or `timedelta`.
+    :param recovery_interval: an interval in seconds to recover energy
+    :type recovery_interval: number or `timedelta`
     :param recovery_quantity: a quantity of once energy recovery. Defaults to
                               ``1``.
     """
@@ -92,7 +93,7 @@ class Energy(object):
                 recovery_interval = total_seconds(recovery_interval)
         if not isinstance(recovery_interval, (int, float)):
             raise TypeError('recovery_interval should be number')
-        self.max = max
+        self._max = max
         #: The interval in seconds to recover energy.
         self.recovery_interval = recovery_interval
         #: The quantity of once energy recovery.
@@ -137,7 +138,7 @@ class Energy(object):
                      time in UTC.
         """
         time = timestamp(time)
-        current = self.current()
+        current = self.current(time)
         if current < quantity:
             raise ValueError('Not enough energy')
         if current - quantity < self.max <= current:
@@ -243,15 +244,58 @@ class Energy(object):
         """Type-casting to `bool`."""
         return bool(self.__int__(time))
 
-    def __eq__(self, val):
-        """Checks if same energy. An operand can be :class:`Energy` or number.
+    def __eq__(self, val, time=None):
+        """:class:`Energy` == `val`.
+
+        :param val: the operand
+        :type val: :class:`Energy` or number
         """
         if isinstance(val, type(self)):
             return self.__getstate__() == val.__getstate__()
         elif isinstance(val, (int, float)):
-            return float(self) == val
+            return float(self.current(time)) == val
         return False
 
+    def __lt__(self, val, time=None):
+        """:class:`Energy` < `val`.
+
+        :param val: the operand
+        :type val: number
+
+        .. versionadded:: 0.1.3
+        """
+        return self.current(time) < val
+
+    def __le__(self, val, time=None):
+        """:class:`Energy` <= `val`.
+
+        :param val: the operand
+        :type val: number
+
+        .. versionadded:: 0.1.3
+        """
+        return self.current(time) <= val
+
+    def __gt__(self, val, time=None):
+        """:class:`Energy` > `val`.
+
+        :param number val: the operand
+        :type val: number
+
+        .. versionadded:: 0.1.3
+        """
+        return self.current(time) > val
+
+    def __ge__(self, val, time=None):
+        """:class:`Energy` >= `val`.
+
+        :param val: the operand
+        :type val: number
+
+        .. versionadded:: 0.1.3
+        """
+        return self.current(time) >= val
+
     def __iadd__(self, val, time=None):
         """Increases by the value.
 
